#!/bin/bash

MIRROR_SERVER="http://mirror.vitalinux.educa.aragon.es"

function create_source_list() {
    local _SRV=$1
    local proxy_file="/etc/apt/apt.conf.d/01cache_proxy"
    . /etc/default/vx-dga-variables/vx-dga-variables-general.conf
    #Comprobamos lo primero si el servidor caché está en la red
    if [ "$IPCACHE" != "" ] && nc -z "$IPCACHE" 3142 -w5 >/dev/null 2>&1; then
        echo "--> Servidor Cache que ofrece servicio APT-CACHER ..."
        echo "--> Se va a configurar al Servidor Cache como servidor APT-CACHER de software ..."

        echo "# Mod por migasfree-launcher: Hay conexión con el servidor APT-CACHER $IPCACHE" >/etc/apt/sources.list

        #Configuramos apt-proxy
        echo "Acquire::http { Proxy \"http://$IPCACHE:3142\"; };" >$proxy_file
        echo 'Acquire::https { Proxy "false"; };' >>$proxy_file
    else
        echo "# Mod por migasfree-launcher: NO hay conexión con algun servidor Caché" >/etc/apt/sources.list
        # Borrar el posible archivo generado anteriormente del proxy-cache
        if test -f $proxy_file; then
            rm -f $proxy_file
        fi
    fi
    # Crearmos las lineas del mirror
    cat >>/etc/apt/sources.list <<EOF
# Ubuntu Base Respositorios
deb ${_SRV}/ubuntu bionic main restricted universe multiverse
deb ${_SRV}/ubuntu bionic-updates main restricted universe multiverse
deb ${_SRV}/ubuntu bionic-security main restricted multiverse universe
deb ${_SRV}/ubuntu bionic-backports main restricted multiverse universe

# Libre Office 7.3
deb ${_SRV}/libreoffice-7-3 bionic main

# Chrome. Solo para 64 bits
deb [arch=amd64] ${_SRV}/google stable main

# Partners Ubuntu
deb ${_SRV}/canonical-partner bionic partner

# OpenJDK
deb ${_SRV}/openjdk-r bionic main

# Gimp 210 PPA
deb ${_SRV}/gimp210 bionic main

# Musescore3 PPA
deb ${_SRV}/musescore3 bionic main

# Shutter PPA
deb ${_SRV}/shutter bionic main

# Freecad PPA
deb ${_SRV}/freecad bionic main

EOF
}

# Función para revisar e instalar claves. Primer parámetro es la clave y segundo el servidor de claves
function install_apt_key() {
    # Ahora el ID de la clave son los 4 grupos de 4 de la huella larga....
    # Para descargarla, solo deberemos quitar los espacios de la huella para buscarla en el server
    if ! (apt-key list | grep "${1}") >/dev/null 2>&1; then
        echo "Clave ${3} no encontrada...Instalando"
        KEY=${1// /}
        apt-key adv --keyserver "${2}" --recv-keys "${KEY}"
        return $?
    fi
}

function searchkey_local_install() {
    # Por rapidez, podemos darle instalar la clave si tenemos la misma sin recurir al server de keys
    ## Ventajas: rapidez
    ## Desventaja: si cambia la clave, hay que actualizar la función
    # La podemos extraer de un equipo que ya la tenga con: apt-key export "089EBE08314DF160"
    if ! (apt-key list | grep "${1}") >/dev/null 2>&1; then
        KEY=${1// /}
        ${KEY} | apt-key add - >/dev/null 2>&1
    fi
}
function EA8CACC073C3DB2A() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----
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=Hd0U
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 3BDAAC08614C4B38() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ES3pREAEEANqbN/8njQThILTmkmcRwycvAk25c7lNHxvYnmdNvcuFVMYN4oET
biZIBM0UuUcXF+6okmhvwf/XFNLWHDcFcozzEN9hvDuJIeSSImIeaGkrvGqQeEaS
dt+gC4cmm8499s4bGXvwX/KzC2U58FPFmNsMTQD4iVi7hju4hhfsrQ97ABEBAAG0
E0xhdW5jaHBhZCBvdHRvMDYyMTeItgQTAQIAIAUCS3pREAIbAwYLCQgHAwIEFQII
AwQWAgMBAh4BAheAAAoJEDvarAhhTEs4Rj4D/0xEqBsaaIPjTVopB+wg47zikvof
RuuTOOhC9H+x4qmS+NQttYbjf56pKREqCxMrt0ptaiuv6mkpNEPnr4tBVEsfNZKT
BdtkIUAvoBC/DsjaVtsjK0TKPX8BhtM+2J2IhToQ6AdFv3kM7EXBMTgxFGHrv796
aOeQzloOMzje+ijFiQEcBBABAgAGBQJTtSMgAAoJECA9PDILJjusGsQH/iWStp8M
rp7RWrQCeIlUvpf3BiDjvhb3c6/Yt8qFeGG/6u8UfHO1IHXHNcOhFxWE1m6UgaeZ
/jGFn8IxB0RmEKq4gqqRauZs3RlnfUX9JT1rAt6A2OwcxqBkjFIyFzGChhIt/HK9
jzB/bpQ6WX0s9NImJ8Ms5nUOrZU2XOzwQjfbi13XfJaAH7vpgrDXiyTfozwvJC5f
vkOgkx3VLge6PplAHbmwHRzFYFfi5kMxUPe33Z25zoKo8b6petL0GHex8GPsGcFl
wCWkRWV71Zmzix3lJ1cv7uc4IuvMRqSZkpbUFyh15vbEjA+2LeHXPVwcHj/DGFvh
48AuQBfUtDoRew8=
=+7P0
    -----END PGP PUBLIC KEY BLOCK-----'
}
function 04E482780EC0BBD2() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ESXhUyQEEAK81+sxhhYvf5rjwnT+4FMkg+Gfc36r0DoT2+OtPcASK7Y+z3Xr/
ACzxQxrr5joyP6lpvIG9jClZ4zCuOi83odcKKq2xmwMCne+FBCAeHpPqWtWIrbY7
UxVw8M1Rmq0F6c79RQQf08ZVUK4qP9n12XRK2Peg93ME25Hxa5lL3GuvABEBAAG0
J0xhdW5jaHBhZCBQUEEgZm9yIE11c2VTY29yZSBNYWludGFpbmVyc4i2BBMBAgAg
BQJJeFTJAhsDBgsJCAcDAgQVAggDBBYCAwECHgECF4AACgkQBOSCeA7Au9KeQwP/
chCH0/kMcVmyhlLHU60pzdcAbTVGqWNsrmWDCq6I9dK/OxGKqoXd5injHD9/v5di
gBP6hKQuofL0Zhfk3wDcp930hoUTh2Gg1JSYqoowcGkzbsITN6tN3mxuweFlMK4v
3P/l9ji5rej2ptteB8wKD2S62S4fdiyZh13f5bWZwMw=
=yH0/
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 089EBE08314DF160() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ESgc8TwEEANnh7UAVSnJoE8fyLMss5VUuG+1Bw5W2XWEyxuOCfMMAnJq4FY7Y
OjaFwX37KdPTy5/+NVqegazUbB3WV8d21aRhN977HXYztt/1Ft73m30FLbZC3vRw
aMg5oaWQ/XAy9ONY8QND/ahhSNf3d8wyrfAlG2RLaUeASDXqMBOU2fKVABEBAAG0
GkxhdW5jaHBhZCB1YnVudHVnaXMtc3RhYmxliLYEEwECACAFAkoHPE8CGwMGCwkI
BwMCBBUCCAMEFgIDAQIeAQIXgAAKCRAInr4IMU3xYG3iA/0dnVOYqpLayEgzmlJ6
mwJnVKcL+tGRfNsKQTHe77skFBcO/YyLez29HJJJS0xGtkZ+bUEQ3mdKnV/jGK4y
geSouItfz3fM3/PvVbZMbARUTzOdIR/Hv8GUyVhY3dPR8NEyw0Op41kCOuxZBVU9
85IQHDDQe6Fw1q6IFjOES0NMjQ==
=gZdQ
-----END PGP PUBLIC KEY BLOCK-----
    '
}
function 005EAE8119BB5BCA() {
    echo '-----BEGIN PGP PUBLIC KEY BLOCK-----

mI0ETYF+BAEEAK1n4CPNzdG/rTNvteUkHOiSikl07GJl7jh8RjL4T2BA3g2J0M0g
x20gOfc2Srbmg676cdf2kIzhfVPbjvWJnDYsFS1BOa0ZsKb0xN6lZzMU2lhmPMgF
jJJk94BqeLlxr9wSqmOkR8X3yDtNWbZ+5xO1wDUP4GDZcCwesVsWfdXZABEBAAG0
JUxhdW5jaHBhZCBQUEEgZm9yIEZyZWVDQUQgbWFpbnRhaW5lcnOIuAQTAQIAIgUC
TYF+BAIbAwYLCQgHAwIGFQgCCQoLBBYCAwECHgECF4AACgkQAF6ugRm7W8oktwP+
Nzk9OEg3kl8fNd9JeTWrw2UnisfPOIV7HTATpLqnXZQOQ+Q7QjsRL6yRMj+U6OWa
9pgDrljJyg77DFCcHipCrR5LiXdxzzK2Z2wbStxsS2U3v7HJaXw4gmYAGyahswLa
RzbmV95JXeFAGjXM5yH6FTxbzGdH/IaXN1ASMMZQedU=
=3tnf
-----END PGP PUBLIC KEY BLOCK-----
    '
}

echo "=> Seguimos con la creación del sources.list ...."

# Revisión e instalación de las claves necesarias:
# Libreoffice
install_apt_key "83FB A175 1378 B444" keyserver.ubuntu.com libreoffice
# openjdk-r
install_apt_key "EB9B 1D88 86F4 4E2A" keyserver.ubuntu.com openjdk

# Instalamos claves de ppas en mirror también, pero sin usar el server de claves (herencia de falla)
# Shutter
searchkey_local_install "EA8C ACC0 73C3 DB2A"
# Gimp210
searchkey_local_install "3BDA AC08 614C 4B38"
# Musescore
searchkey_local_install "04E4 8278 0EC0 BBD2"
# UbuntuGis
searchkey_local_install "089E BE08 314D F160"
# Freecad
searchkey_local_install "005E AE81 19BB 5BCA"

# Chrome. No hace uso del servidores de claves, sino de uno propio
# Primero borraríamos si diera errores:
#(apt-key list | grep D38B4796)  > /dev/null 2>&1 && \
# echo "Borrando clave Google antigua D38B4796" && \
# apt-key del D38B4796 > /dev/null
if ! (apt-key list | grep -q "7721 F63B D38B 4796") >/dev/null 2>&1; then
    echo "Clave Google no encontrada...Instalando"
    wget -q -O - https://dl.google.com/linux/linux_signing_key.pub | apt-key add - >/dev/null
fi

# Limpiar los sources que existan antiguos
# Libreoffice
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*libreoffice.*list$' -exec mv '{}' '{}'.save \;
# Chrome
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*chrome.*list$' -exec mv '{}' '{}'.save \;
# openjdk-r
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*openjdk-r.*list$' -exec mv '{}' '{}'.save \;
# getdeb
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*getdeb.*list$' -exec mv '{}' '{}'.save \;
# gimp
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*gimp.*list$' -exec mv '{}' '{}'.save \;
# musescore
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*musescore.*list$' -exec mv '{}' '{}'.save \;
# shutter
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*shutter.*list$' -exec mv '{}' '{}'.save \;
# freecad
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*freecad.*list$' -exec mv '{}' '{}'.save \;
# Canonical?
find /etc/apt/sources.list.d/ -regextype posix-egrep -regex '.*canonical.*list$' -exec mv '{}' '{}'.save \;

# Creamos el sources.list
create_source_list $MIRROR_SERVER
